@@ -25,8 +25,6 @@ CONF_AUTOMATIC_FILENAME='/etc/dnf/automatic.conf'
 DISTROVERPKG=('system-release(releasever)', 'system-release',
               'distribution-release(releasever)', 'distribution-release',
               'redhat-release', 'suse-release')
-DISTROVER_MAJOR_PKG='system-release(releasever_major)'
-DISTROVER_MINOR_PKG='system-release(releasever_minor)'
 GROUP_PACKAGE_TYPES = ('mandatory', 'default', 'conditional') # :api
 INSTALLONLYPKGS=['kernel', 'kernel-PAE',
                  'installonlypkg(kernel)',
@@ -51,8 +49,8 @@ VERBOSE_LEVEL=6
 PREFIX=NAME.lower()
 PROGRAM_NAME=NAME.lower()  # Deprecated - no longer used, Argparser prints program name based on sys.argv
 PLUGINCONFPATH = '/etc/dnf/plugins'  # :api
-PLUGINPATH = '/usr/lib/python3.9/site-packages/dnf-plugins'
-VERSION='4.14.0'
+PLUGINPATH = '/usr/lib/python3.12/site-packages/dnf-plugins'
+VERSION='4.20.0'
 USER_AGENT = "dnf/%s" % VERSION
 
 BUGTRACKER_COMPONENT=NAME.lower()
